@@ -18,14 +18,14 @@
 #define __GSWITCHIT_CAPPLET_H__
 
 #include "gtk/gtk.h"
-#include "../common/gswitchit_config.h"
+#include "../common/gswitchit_applet_config.h"
 #include "../common/gswitchit_util.h"
 
 typedef struct _GSwitchItCapplet
 {
   GtkWidget *capplet;
-  GSwitchItConfig config;
-  gboolean stateChanged;
+  GSwitchItAppletConfig appletConfig;
+  GSwitchItXkbConfig xkbConfig;
 }
 GSwitchItCapplet;
 
